@@ -343,9 +343,12 @@ func TestDirOpen(t *testing.T) {
 func TestDirCreate(t *testing.T) {
 	_, vfs, dir, _ := dirCreate(t)
 
+	origModTime := dir.ModTime()
+	time.Sleep(100 * time.Millisecond) // for low rez Windows timers
 	file, err := dir.Create("potato", os.O_WRONLY|os.O_CREATE)
 	require.NoError(t, err)
 	assert.Equal(t, int64(0), file.Size())
+	assert.True(t, dir.ModTime().After(origModTime))
 
 	fd, err := file.Open(os.O_WRONLY | os.O_CREATE)
 	require.NoError(t, err)
@@ -385,8 +388,11 @@ func TestDirMkdir(t *testing.T) {
 	_, err := dir.Mkdir("file1")
 	assert.Error(t, err)
 
+	origModTime := dir.ModTime()
+	time.Sleep(100 * time.Millisecond) // for low rez Windows timers
 	sub, err := dir.Mkdir("sub")
 	assert.NoError(t, err)
+	assert.True(t, dir.ModTime().After(origModTime))
 
 	// check the vfs
 	checkListing(t, dir, []string{"file1,14,false", "sub,0,true"})
@@ -488,8 +494,11 @@ func TestDirRemoveAll(t *testing.T) {
 func TestDirRemoveName(t *testing.T) {
 	r, vfs, dir, _ := dirCreate(t)
 
+	origModTime := dir.ModTime()
+	time.Sleep(100 * time.Millisecond) // for low rez Windows timers
 	err := dir.RemoveName("file1")
 	require.NoError(t, err)
+	assert.True(t, dir.ModTime().After(origModTime))
 	checkListing(t, dir, []string(nil))
 	root, err := vfs.Root()
 	require.NoError(t, err)
@@ -538,8 +547,11 @@ func TestDirRename(t *testing.T) {
 	dir = node.(*Dir)
 
 	// Rename a file
+	origModTime := dir.ModTime()
+	time.Sleep(100 * time.Millisecond) // for low rez Windows timers
 	err = dir.Rename("file1", "file2", root)
 	assert.NoError(t, err)
+	assert.True(t, dir.ModTime().After(origModTime))
 	checkListing(t, root, []string{"dir2,0,true", "file2,14,false"})
 	checkListing(t, dir, []string{"file3,15,false"})
 
@@ -577,6 +589,19 @@ func TestDirRename(t *testing.T) {
 	vfs.Opt.ReadOnly = true
 	err = dir.Rename("potato", "tuba", dir)
 	assert.Equal(t, EROFS, err)
+
+	// Rename a dir, check that key was correctly renamed in dir.parent.items
+	vfs.Opt.ReadOnly = false
+	_, ok := dir.parent.items["dir2"]
+	assert.True(t, ok, "dir.parent.items should have 'dir2' key before rename")
+	_, ok = dir.parent.items["dir3"]
+	assert.False(t, ok, "dir.parent.items should not have 'dir3' key before rename")
+	dir.renameTree("dir3") // rename dir2 to dir3
+	_, ok = dir.parent.items["dir2"]
+	assert.False(t, ok, "dir.parent.items should not have 'dir2' key after rename")
+	d, ok := dir.parent.items["dir3"]
+	assert.True(t, ok, fmt.Sprintf("expected to find 'dir3' key in dir.parent.items after rename, got %v", dir.parent.items))
+	assert.Equal(t, dir, d, `expected renamed dir to match value of dir.parent.items["dir3"]`)
 }
 
 func TestDirStructSize(t *testing.T) {
